#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.4
visibility:           public
id:                   doctest-driver-gen-0.3.0.4-CBcHIf9RF1xLnSPrexytXu
key:                  doctest-driver-gen-0.3.0.4-CBcHIf9RF1xLnSPrexytXu
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2021
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  45e1f23760d475838092886152f06190
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-8.10.5/site-local/doctest-driver-gen-0.3.0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/doctest-driver-gen-0.3.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/doctest-driver-gen-0.3.0.4
hs-libraries:         HSdoctest-driver-gen-0.3.0.4-CBcHIf9RF1xLnSPrexytXu
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

